import click
import signal
import sys
from importlib.metadata import version
from overseer.config import EnvConfig
from overseer.scanner import ScanManager
from overseer.database import DatabaseConnector
from flask import Flask
from flask.cli import FlaskGroup

__version__ = version("overseer")

app = Flask(__name__)
config = EnvConfig()
database = DatabaseConnector(config.DATA_PATH)
scan_manager = ScanManager()


def signal_handler(sig, frame):
    scan_manager.shutdown()
    sys.exit(0)


def create_app():
    return app


@click.group(cls=FlaskGroup, create_app=create_app)
def cli():
    """Management script for the application."""


# Handle SIGINT
signal.signal(signal.SIGINT, signal_handler)

# Import all flask views
import overseer.overseer  # noqa: E501,F401,E402
